@@ -1,8 +1,11 @@
-import os
-from .file_io import FileIO
 from .get_arguments import get_argument
+from .file_io import FileIO
 from datetime import datetime
+
 import requests
+import os
+import json
+
 
 class Http(FileIO):
 
@@ -14,7 +17,13 @@ class Http(FileIO):
     def download(self, local_path, remote_path=None):
         if remote_path is None:
             remote_path = self.get_remote_path()
-        get_response = requests.get(remote_path,stream=True)
+
+        headers = {}
+        headers_from_env = os.getenv('HEADERS')
+        if headers_from_env is not None:
+            headers.update(json.loads(headers_from_env))
+
+        get_response = requests.get(remote_path, stream=True, headers=headers)
         
         #original_file_name  = remote_path.split("/")[-1] # original name of the file. Ignored for now, but leave this for future needs
  
